.. _api_documentation:

API documentation
=================

Authenticator object
--------------------

.. module:: yampy
.. autoclass:: Authenticator
   :members:

Yammer object
-------------

.. module:: yampy
.. autoclass:: Yammer
   :members:

MessagesAPI object
------------------

.. module:: yampy.apis
.. autoclass:: MessagesAPI
   :members:

RelationshipsAPI object
-----------------------

.. module:: yampy.apis
.. autoclass:: RelationshipsAPI
   :members:

UsersAPI object
---------------

.. module:: yampy.apis
.. autoclass:: UsersAPI
   :members:

GroupsAPI object
---------------

.. module:: yampy.apis
.. autoclass:: GroupsAPI
   :members:

TopicsAPI object
----------------

.. module:: yampy.apis
.. autoclass:: TopicsAPI
   :members:

Client object
-------------

.. module:: yampy.client
.. autoclass:: Client
   :members:

GenericModel object
-------------------

.. module:: yampy.models
.. autoclass:: GenericModel
   :members:

Errors
------

.. automodule:: yampy.errors
   :members:
